CellOffset class

Constructors

CellOffset(int x, int y)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x int
final
y int
final

Methods

isAfter(CellOffset other) bool
isAfterOrSame(CellOffset other) bool
isAfterWithTolerance(CellOffset other) bool
isAtSameColumn(CellOffset other) bool
isAtSameRow(CellOffset other) bool
isBefore(CellOffset other) bool
isBeforeOrSame(CellOffset other) bool
isEqual(CellOffset other) bool
isWithin(BufferRange range) bool
moveRelative(CellOffset offset, {int? maxX, int? maxY}) CellOffset
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator +(CellOffset other) CellOffset
operator ==(Object other) bool
The equality operator.
override